/*
 * file simpleGesture.ino
 *
 * @ https://github.com/DFRobot/DFRobot_Gesture_Touch
 *
 * example for DFRobot Gesture&Touch sensor
 *
 * sensor event will print on your serial monitor
 *
 * for esp32, rx_pin = D5, tx_pin = D6
 *
 * Copyright   [DFRobot](http://www.dfrobot.com), 2016
 * Copyright   GNU Lesser General Public License
 *
 * version  V1.0
 * date  2018-10-19
 */
 
#include "DFRobot_Gesture_Touch.h"
#include <Servo.h>

#ifdef __AVR__
  #include "SoftwareSerial.h"
  SoftwareSerial    mySerial(10, 11);         // example for uno, use software serial
#elif defined ESP_PLATFORM
  #include "HardwareSerial.h"
  HardwareSerial    mySerial(1);
#endif



DFRobot_Gesture_Touch   DFGT(&mySerial);    // init sensor object, request write and read function
#define Buzz 4 //蜂鸣器
#define LED_G 5 //绿色LED
#define LED_Y 6 //黄色LED
bool lock = 0;  //可以输入手势标志
int password = 1234; //设定密码
int S = 0;  //记录手势的代表数字
int P = 0;  //记录手势的输入次数
int O = 0;  //记录密码

Servo myservo;//舵机函数

void setup()
{
  Serial.begin(115200);
  mySerial.begin(9600);
  delay(500);
  while(mySerial.available())  // flush serial buffer
    mySerial.read();
  Serial.println("gesture&touch sensor test");

  DFGT.setGestureDistance(20);             // suggest default value
  DFGT.enableFunction(DFGT_FUN_ALL);       // enable all functions
  //DFGT.disableFunction(DFGT_FUN_RIGHT | DFGT_FUN_LEFT);    // disable function test
   DFGT.enableFunction(DFGT_FUN_RIGHT | DFGT_FUN_LEFT);     // enable function test
  // DFGT.setSleep(4);                        // set auto sleep time out, in sleep mode, something  approach will weak it up
  pinMode(Buzz,OUTPUT);
  pinMode(LED_G,OUTPUT);
  pinMode(LED_Y,OUTPUT);
  myservo.attach(3);
  myservo.write(0);
  delay(1500);
  myservo.detach();
  digitalWrite(LED_Y,LOW);
  digitalWrite(LED_G,LOW);
}

void record()
{
  if( lock )
  {
    O = O*10 + S ;//密码移位记录
    P++ ;
    if( P == 4 )
    {
      lock = 0;
      if (O == password)
      {
        for(int i=0 ; i<3;i++)
        {
        digitalWrite(Buzz,HIGH);
        delay(50);
        digitalWrite(Buzz,LOW);
        delay(50);        
          }
        digitalWrite(LED_G,HIGH);
        digitalWrite(LED_Y,LOW);
         delay(200);
        myservo.attach(3);
        myservo.write(100);
        delay(2000);
        myservo.detach(); 
        delay(2000);//开门等待进入
        digitalWrite(LED_G,LOW);
        myservo.attach(3);
        myservo.write(0); 
        delay(1500);       
        myservo.detach(); 
        }
        else
        {
        digitalWrite(Buzz,HIGH);
        for(int i=0;i<3;i++)
        {
         digitalWrite(LED_Y,LOW);
         delay(200);
         digitalWrite(LED_Y,HIGH);
         delay(200);
          }
        digitalWrite(LED_Y,LOW);
        digitalWrite(Buzz,LOW);
          }
       O = 0;
       P = 0;
      }
    }
  }

void loop()
{
  int8_t    rslt = DFGT.getAnEvent();  // get an event that data saved in serial buffer
  if(rslt != DF_ERR) {
    // DFGT.setSleep(DFGT_SLEEP_DISABLE);  // disable auto sleep
    switch(rslt) {
      case DFGT_EVT_BACK: {
        Serial.println("get event back");

        digitalWrite(Buzz,HIGH);
        delay(50);
        digitalWrite(Buzz,LOW);
        delay(50); 
        S = 2;
        record();     
      } break;
      case DFGT_EVT_FORWARD: {
        Serial.println("get event forward");

        digitalWrite(Buzz,HIGH);
        delay(50);
        digitalWrite(Buzz,LOW);
        delay(50);
        S = 1;
        record();        
      } break;
      case DFGT_EVT_RIGHT: {

        digitalWrite(Buzz,HIGH);
        delay(50);
        digitalWrite(Buzz,LOW);
        delay(50);
        Serial.println("get event right");
        S = 4;
        record();
      } break;
      case DFGT_EVT_LEFT: {
        Serial.println("get event left");

        digitalWrite(Buzz,HIGH);
        delay(50);
        digitalWrite(Buzz,LOW);
        delay(50);
        S = 3;
        record();        
      } break;
      case DFGT_EVT_PULLUP: {
        Serial.println("get event pull up");
      } break;
      case DFGT_EVT_PULLDOWN: { 
        Serial.println("get event pull down");     
      } break;
      case DFGT_EVT_PULLREMOVE: {
        Serial.println("get event pull and remove");
        
        digitalWrite(Buzz,HIGH);
        delay(200);
        digitalWrite(Buzz,LOW);
        delay(200); 
        lock = 1;//开始记录输入手势密码
        digitalWrite(LED_Y,HIGH);
      } break;
      case DFGT_EVT_TOUCH1: {
        Serial.println("get event touch1");
        digitalWrite(Buzz,HIGH);
        delay(50);
        digitalWrite(Buzz,LOW);
        delay(50);        
      } break;
      case DFGT_EVT_TOUCH2: {
        Serial.println("get event touch2");
      } break;
      case DFGT_EVT_TOUCH3: {
        Serial.println("get event touch3");
      } break;
      case DFGT_EVT_TOUCH4: {
        Serial.println("get event touch4");
      } break;
      case DFGT_EVT_TOUCH5: {
        Serial.println("get event touch5");
      } break;
    }
  }
}
